from io import StringIO
import pandas as pd

species_table_str = """scientific,xc_common,bn_code,bn_common,bn_mapping_in_xc_dataset,relationship
dendrocygna-autumnalis,blackbelliedwhistlingduck,bbwduc,blackbelliedwhistlingduck,dendrocygna-autumnalis,
anser-caerulescens,snowgoose,snogoo,snowgoose,anser-caerulescens,
anser-albifrons,greaterwhitefrontedgoose,gwfgoo,greaterwhitefrontedgoose,anser-albifrons,
branta-bernicla,brantgoose,brant,brant,branta-bernicla,"Same species, different common name"
branta-hutchinsii,cacklinggoose,cacgoo1,cacklinggoose,branta-hutchinsii,
branta-canadensis,canadagoose,cangoo,canadagoose,branta-canadensis,
cygnus-olor,muteswan,mutswa,muteswan,cygnus-olor,
cygnus-buccinator,trumpeterswan,truswa,trumpeterswan,cygnus-buccinator,
cygnus-columbianus,tundraswan,tunswa,tundraswan,cygnus-columbianus,
alopochen-aegyptiaca,egyptiangoose,egygoo,egyptiangoose,alopochen-aegyptiaca,
aix-sponsa,woodduck,wooduc,woodduck,aix-sponsa,
spatula-discors,bluewingedteal,buwtea,bluewingedteal,spatula-discors,
spatula-clypeata,northernshoveler,norsho,northernshoveler,spatula-clypeata,
mareca-strepera,gadwall,gadwal,gadwall,mareca-strepera,
mareca-penelope,eurasianwigeon,eurwig,eurasianwigeon,mareca-penelope,
anas-platyrhynchos,mallard,mallar3,mallard,anas-platyrhynchos,
anas-carolinensis,greenwingedteal,,,,XC split with only one species in the ABA area; BirdNet's name for the complex (anas-crecca) refers to the XC species outside the ABA area
somateria-mollissima,commoneider,comeid,commoneider,somateria-mollissima,
clangula-hyemalis,longtailedduck,lotduc,longtailedduck,clangula-hyemalis,
bucephala-clangula,commongoldeneye,comgol,commongoldeneye,bucephala-clangula,
mergus-merganser,commonmerganser,commer,commonmerganser,mergus-merganser,
ortalis-vetula,plainchachalaca,placha,plainchachalaca,ortalis-vetula,
oreortyx-pictus,mountainquail,mouqua,mountainquail,oreortyx-pictus,
colinus-virginianus,northernbobwhite,norbob,northernbobwhite,colinus-virginianus,
callipepla-squamata,scaledquail,scaqua,scaledquail,callipepla-squamata,
callipepla-californica,californiaquail,calqua,californiaquail,callipepla-californica,
callipepla-gambelii,gambelsquail,gamqua,gambelsquail,callipepla-gambelii,
francolinus-francolinus,blackfrancolin,blkfra,blackfrancolin,francolinus-francolinus,
perdix-perdix,graypartridge,grypar,graypartridge,perdix-perdix,
gallus-gallus,redjunglefowl,redjun,redjunglefowl,gallus-gallus,
phasianus-colchicus,commonpheasant,rinphe,ringneckedpheasant,phasianus-colchicus,"Same species, different common name"
centrocercus-urophasianus,sagegrouse,saggro,greatersagegrouse,centrocercus-urophasianus,"Same species, different common name"
lagopus-lagopus,willowptarmigan,wilpta,willowptarmigan,lagopus-lagopus,
lagopus-muta,rockptarmigan,rocpta1,rockptarmigan,lagopus-muta,
lagopus-leucura,whitetailedptarmigan,whtpta1,whitetailedptarmigan,lagopus-leucura,
dendragapus-fuliginosus,sootygrouse,soogro1,sootygrouse,dendragapus-fuliginosus,
tympanuchus-phasianellus,sharptailedgrouse,shtgro,sharptailedgrouse,tympanuchus-phasianellus,
tympanuchus-cupido,greaterprairiechicken,grpchi,greaterprairiechicken,tympanuchus-cupido,
meleagris-gallopavo,wildturkey,wiltur,wildturkey,meleagris-gallopavo,
tachybaptus-dominicus,leastgrebe,leagre,leastgrebe,tachybaptus-dominicus,
podilymbus-podiceps,piedbilledgrebe,pibgre,piedbilledgrebe,podilymbus-podiceps,
podiceps-auritus,hornedgrebe,horgre,hornedgrebe,podiceps-auritus,
podiceps-grisegena,redneckedgrebe,rengre,redneckedgrebe,podiceps-grisegena,
podiceps-nigricollis,blackneckedgrebe,eargre,earedgrebe,podiceps-nigricollis,"Same species, different common name"
aechmophorus-occidentalis,westerngrebe,wesgre,westerngrebe,aechmophorus-occidentalis,
columba-livia,rockdove,rocpig,rockpigeon,columba-livia,"Same species, different common name"
patagioenas-flavirostris,redbilledpigeon,rebpig1,redbilledpigeon,patagioenas-flavirostris,
patagioenas-fasciata,bandtailedpigeon,batpig1,bandtailedpigeon,patagioenas-fasciata,
streptopelia-decaocto,eurasiancollareddove,eucdov,eurasiancollareddove,streptopelia-decaocto,
spilopelia-chinensis,spotteddove,spodove,spotteddove,spilopelia-chinensis,"Same species, different scientific name"
geopelia-striata,zebradove,zebdov,zebradove,geopelia-striata,
columbina-inca,incadove,incdov,incadove,columbina-inca,
columbina-passerina,commongrounddove,cogdov,commongrounddove,columbina-passerina,
leptotila-verreauxi,whitetippeddove,whtdov,whitetippeddove,leptotila-verreauxi,
zenaida-asiatica,whitewingeddove,whwdov,whitewingeddove,zenaida-asiatica,
zenaida-macroura,mourningdove,moudov,mourningdove,zenaida-macroura,
coccyzus-americanus,yellowbilledcuckoo,yebcuc,yellowbilledcuckoo,coccyzus-americanus,
coccyzus-erythropthalmus,blackbilledcuckoo,bkbcuc,blackbilledcuckoo,coccyzus-erythropthalmus,
geococcyx-californianus,greaterroadrunner,greroa,greaterroadrunner,geococcyx-californianus,
crotophaga-sulcirostris,groovebilledani,grbani,groovebilledani,crotophaga-sulcirostris,
chordeiles-acutipennis,lessernighthawk,lesnig,lessernighthawk,chordeiles-acutipennis,
chordeiles-minor,commonnighthawk,comnig,commonnighthawk,chordeiles-minor,
nyctidromus-albicollis,pauraque,compau,commonpauraque,nyctidromus-albicollis,"Same species, different common name"
phalaenoptilus-nuttallii,commonpoorwill,compoo,commonpoorwill,phalaenoptilus-nuttallii,
antrostomus-carolinensis,chuckwillswidow,chwwid,chuckwillswidow,antrostomus-carolinensis,
antrostomus-vociferus,easternwhippoorwill,whip-p1,easternwhippoorwill,antrostomus-vociferus,
antrostomus-arizonae,mexicanwhippoorwill,souwpw1,mexicanwhippoorwill,antrostomus-arizonae,
eugenes-fulgens,rivolishummingbird,maghum1,rivolishummingbird,eugenes-fulgens,
lampornis-clemenciae,bluethroatedmountaingem,buthum,bluethroatedhummingbird,lampornis-clemenciae,"Same species, different common name"
calypte-anna,annashummingbird,annhum,annashummingbird,calypte-anna,
selasphorus-platycercus,broadtailedhummingbird,brthum,broadtailedhummingbird,selasphorus-platycercus,
selasphorus-rufus,rufoushummingbird,rufhum,rufoushummingbird,selasphorus-rufus,
amazilia-violiceps,violetcrownedhummingbird,vichum,violetcrownedhummingbird,amazilia-violiceps,
laterallus-jamaicensis,blackrail,blkrai,blackrail,laterallus-jamaicensis,
rallus-obsoletus,ridgwaysrail,ridrai1,ridgwaysrail,rallus-obsoletus,
rallus-elegans,kingrail,kinrai4,kingrail,rallus-elegans,
rallus-limicola,virginiarail,virrai,virginiarail,rallus-limicola,
porzana-carolina,sora,sora,sora,porzana-carolina,
porphyrio-martinica,purplegallinule,purgal2,purplegallinule,porphyrio-martinica,
gallinula-galeata,commongallinule,comgal1,commongallinule,gallinula-galeata,
fulica-americana,americancoot,y00475,americancoot,fulica-americana,
aramus-guarauna,limpkin,limpki,limpkin,aramus-guarauna,
antigone-canadensis,sandhillcrane,sancra,sandhillcrane,antigone-canadensis,
himantopus-mexicanus,blackneckedstilt,bknsti,blackneckedstilt,himantopus-mexicanus,
recurvirostra-americana,americanavocet,ameavo,americanavocet,recurvirostra-americana,
pluvialis-squatarola,grayplover,bkbplo,blackbelliedplover,pluvialis-squatarola,"Same species, different common name"
pluvialis-dominica,americangoldenplover,amgplo,americangoldenplover,pluvialis-dominica,
charadrius-semipalmatus,semipalmatedplover,semplo,semipalmatedplover,charadrius-semipalmatus,
charadrius-vociferus,killdeer,killde,killdeer,charadrius-vociferus,
bartramia-longicauda,uplandsandpiper,uplsan,uplandsandpiper,bartramia-longicauda,
numenius-phaeopus,whimbrel,whimbr,whimbrel,numenius-phaeopus,
numenius-americanus,longbilledcurlew,lobcur,longbilledcurlew,numenius-americanus,
limosa-fedoa,marbledgodwit,margod,marbledgodwit,limosa-fedoa,
arenaria-interpres,ruddyturnstone,rudtur,ruddyturnstone,arenaria-interpres,
calidris-canutus,redknot,redkno,redknot,calidris-canutus,
calidris-himantopus,stiltsandpiper,stisan,stiltsandpiper,calidris-himantopus,
calidris-alba,sanderling,sander,sanderling,calidris-alba,
calidris-alpina,dunlin,dunlin,dunlin,calidris-alpina,
calidris-maritima,purplesandpiper,pursan,purplesandpiper,calidris-maritima,
calidris-bairdii,bairdssandpiper,baisan,bairdssandpiper,calidris-bairdii,
calidris-minutilla,leastsandpiper,leasan,leastsandpiper,calidris-minutilla,
calidris-fuscicollis,whiterumpedsandpiper,whrsan,whiterumpedsandpiper,calidris-fuscicollis,
calidris-melanotos,pectoralsandpiper,pecsan,pectoralsandpiper,calidris-melanotos,
calidris-pusilla,semipalmatedsandpiper,semsan,semipalmatedsandpiper,calidris-pusilla,
limnodromus-scolopaceus,longbilleddowitcher,lobdow,longbilleddowitcher,limnodromus-scolopaceus,
scolopax-minor,americanwoodcock,amewoo,americanwoodcock,scolopax-minor,
gallinago-delicata,wilsonssnipe,wilsni1,wilsonssnipe,gallinago-delicata,
actitis-macularius,spottedsandpiper,sposan,spottedsandpiper,actitis-macularius,
tringa-solitaria,solitarysandpiper,solsan,solitarysandpiper,tringa-solitaria,
tringa-flavipes,lesseryellowlegs,lesyel,lesseryellowlegs,tringa-flavipes,
tringa-semipalmata,willet,willet1,willet,tringa-semipalmata,
tringa-melanoleuca,greateryellowlegs,greyel,greateryellowlegs,tringa-melanoleuca,
tringa-glareola,woodsandpiper,woosan,woodsandpiper,tringa-glareola,
phalaropus-lobatus,redneckedphalarope,renpha,redneckedphalarope,phalaropus-lobatus,
phalaropus-fulicarius,redphalarope,redpha1,redphalarope,phalaropus-fulicarius,
stercorarius-parasiticus,parasiticjaeger,parjae,parasiticjaeger,stercorarius-parasiticus,
stercorarius-longicaudus,longtailedjaeger,lotjae,longtailedjaeger,stercorarius-longicaudus,
uria-aalge,commonmurre,commur,commonmurre,uria-aalge,
alca-torda,razorbill,razorb,razorbill,alca-torda,
fratercula-arctica,atlanticpuffin,atlpuf,atlanticpuffin,fratercula-arctica,
rissa-tridactyla,blackleggedkittiwake,bklkit,blackleggedkittiwake,rissa-tridactyla,
chroicocephalus-philadelphia,bonapartesgull,bongul,bonapartesgull,chroicocephalus-philadelphia,
leucophaeus-atricilla,laughinggull,laugul,laughinggull,leucophaeus-atricilla,
leucophaeus-pipixcan,franklinsgull,fragul,franklinsgull,leucophaeus-pipixcan,
larus-heermanni,heermannsgull,heegul,heermannsgull,larus-heermanni,
larus-canus,mewgull,mewgul,mewgull,larus-canus,
larus-delawarensis,ringbilledgull,ribgul,ringbilledgull,larus-delawarensis,
larus-californicus,californiagull,calgul,californiagull,larus-californicus,
larus-fuscus,lesserblackbackedgull,lbbgul,lesserblackbackedgull,larus-fuscus,
larus-glaucescens,glaucouswingedgull,glwgul,glaucouswingedgull,larus-glaucescens,
larus-hyperboreus,glaucousgull,glagul,glaucousgull,larus-hyperboreus,
larus-marinus,greatblackbackedgull,gbbgul,greatblackbackedgull,larus-marinus,
gygis-alba,whitetern,whiter,whitetern,gygis-alba,
sternula-antillarum,leasttern,leater1,leasttern,sternula-antillarum,
gelochelidon-nilotica,gullbilledtern,gubter1,gullbilledtern,gelochelidon-nilotica,
hydroprogne-caspia,caspiantern,caster1,caspiantern,hydroprogne-caspia,
chlidonias-niger,blacktern,blkter,blacktern,chlidonias-niger,
sterna-dougallii,roseatetern,roster,roseatetern,sterna-dougallii,
sterna-hirundo,commontern,comter,commontern,sterna-hirundo,
sterna-paradisaea,arctictern,arcter,arctictern,sterna-paradisaea,
sterna-forsteri,forsterstern,forter,forsterstern,sterna-forsteri,
thalasseus-maximus,royaltern,royter1,royaltern,thalasseus-maximus,
thalasseus-sandvicensis,sandwichtern,santer1,sandwichtern,thalasseus-sandvicensis,
thalasseus-elegans,eleganttern,eleter1,eleganttern,thalasseus-elegans,
rynchops-niger,blackskimmer,blkski,blackskimmer,rynchops-niger,
gavia-stellata,redthroatedloon,retloo,redthroatedloon,gavia-stellata,
gavia-arctica,blackthroatedloon,arcloo,arcticloon,gavia-arctica,"Same species, different common name"
gavia-immer,commonloon,comloo,commonloon,gavia-immer,
phoebastria-immutabilis,laysanalbatross,layalb,laysanalbatross,phoebastria-immutabilis,
phoebastria-nigripes,blackfootedalbatross,bkfalb,blackfootedalbatross,phoebastria-nigripes,
fulmarus-glacialis,northernfulmar,norful,northernfulmar,fulmarus-glacialis,
puffinus-puffinus,manxshearwater,manshe,manxshearwater,puffinus-puffinus,
morus-bassanus,northerngannet,norgan,northerngannet,morus-bassanus,
phalacrocorax-brasilianus,neotropiccormorant,neocor,neotropiccormorant,phalacrocorax-brasilianus,
phalacrocorax-auritus,doublecrestedcormorant,doccor,doublecrestedcormorant,phalacrocorax-auritus,
phalacrocorax-carbo,greatcormorant,grecor,greatcormorant,phalacrocorax-carbo,
phalacrocorax-pelagicus,pelagiccormorant,pelcor,pelagiccormorant,phalacrocorax-pelagicus,
botaurus-lentiginosus,americanbittern,amebit,americanbittern,botaurus-lentiginosus,
ixobrychus-exilis,leastbittern,leabit,leastbittern,ixobrychus-exilis,
ardea-herodias,greatblueheron,grbher3,greatblueheron,ardea-herodias,
ardea-alba,greategret,greegr,greategret,ardea-alba,
bubulcus-ibis,westerncattleegret,categr,cattleegret,bubulcus-ibis,XC split with only one species in the ABA area; BirdNet's name for the complex (bubulcus-ibis) refers to the XC species INSIDE the ABA area
nycticorax-nycticorax,blackcrownednightheron,bcnher,blackcrownednightheron,nycticorax-nycticorax,
plegadis-chihi,whitefacedibis,whfibi,whitefacedibis,plegadis-chihi,
pandion-haliaetus,westernosprey,osprey,osprey,pandion-haliaetus,XC split with only one species in the ABA area; BirdNet's name for the complex (pandion-haliaetus) refers to the XC species INSIDE the ABA area
elanoides-forficatus,swallowtailedkite,swtkit,swallowtailedkite,elanoides-forficatus,
aquila-chrysaetos,goldeneagle,goleag,goldeneagle,aquila-chrysaetos,
accipiter-cooperii,coopershawk,coohaw,coopershawk,accipiter-cooperii,
accipiter-gentilis,northerngoshawk,norgos,northerngoshawk,accipiter-gentilis,
rostrhamus-sociabilis,snailkite,snakit,snailkite,rostrhamus-sociabilis,
buteo-plagiatus,grayhawk,gryhaw2,grayhawk,buteo-plagiatus,
buteo-lineatus,redshoulderedhawk,reshaw,redshoulderedhawk,buteo-lineatus,
buteo-platypterus,broadwingedhawk,brwhaw,broadwingedhawk,buteo-platypterus,
buteo-jamaicensis,redtailedhawk,rethaw,redtailedhawk,buteo-jamaicensis,
tyto-furcata,americanbarnowl,,,,XC split with only one species in the ABA area; BirdNet's scientific name for the complex (tyto-alba) refers to the XC species outside the ABA area
psiloscops-flammeolus,flammulatedowl,flaowl,flammulatedowl,psiloscops-flammeolus,
megascops-kennicottii,westernscreechowl,wesowl1,westernscreechowl,megascops-kennicottii,
megascops-asio,easternscreechowl,easowl1,easternscreechowl,megascops-asio,
megascops-trichopsis,whiskeredscreechowl,whsowl1,whiskeredscreechowl,megascops-trichopsis,
bubo-virginianus,greathornedowl,grhowl,greathornedowl,bubo-virginianus,
glaucidium-californicum,northernpygmyowl,,,,XC split with only one species in the ABA area; BirdNet's name for the complex (glaucidium-gnoma) refers to the XC species outside the ABA area
micrathene-whitneyi,elfowl,elfowl,elfowl,micrathene-whitneyi,
athene-cunicularia,burrowingowl,burowl,burrowingowl,athene-cunicularia,
strix-occidentalis,spottedowl,spoowl,spottedowl,strix-occidentalis,
strix-varia,barredowl,brdowl,barredowl,strix-varia,
strix-nebulosa,greatgrayowl,grgowl,greatgrayowl,strix-nebulosa,
asio-otus,longearedowl,loeowl,longearedowl,asio-otus,
asio-flammeus,shortearedowl,sheowl,shortearedowl,asio-flammeus,
aegolius-funereus,borealowl,borowl,borealowl,aegolius-funereus,
aegolius-acadicus,northernsawwhetowl,nswowl,northernsawwhetowl,aegolius-acadicus,
trogon-elegans,eleganttrogon,eletro,eleganttrogon,trogon-elegans,
megaceryle-torquata,ringedkingfisher,rinkin1,ringedkingfisher,megaceryle-torquata,
megaceryle-alcyon,beltedkingfisher,belkin1,beltedkingfisher,megaceryle-alcyon,
chloroceryle-americana,greenkingfisher,grnkin,greenkingfisher,chloroceryle-americana,
melanerpes-erythrocephalus,redheadedwoodpecker,rehwoo,redheadedwoodpecker,melanerpes-erythrocephalus,
melanerpes-formicivorus,acornwoodpecker,acowoo,acornwoodpecker,melanerpes-formicivorus,
melanerpes-uropygialis,gilawoodpecker,gilwoo,gilawoodpecker,melanerpes-uropygialis,
melanerpes-carolinus,redbelliedwoodpecker,rebwoo,redbelliedwoodpecker,melanerpes-carolinus,
sphyrapicus-thyroideus,williamsonssapsucker,wilsap,williamsonssapsucker,sphyrapicus-thyroideus,
sphyrapicus-varius,yellowbelliedsapsucker,yebsap,yellowbelliedsapsucker,sphyrapicus-varius,
sphyrapicus-nuchalis,rednapedsapsucker,rensap,rednapedsapsucker,sphyrapicus-nuchalis,
sphyrapicus-ruber,redbreastedsapsucker,rebsap,redbreastedsapsucker,sphyrapicus-ruber,
picoides-dorsalis,americanthreetoedwoodpecker,attwoo1,americanthreetoedwoodpecker,picoides-dorsalis,
picoides-arcticus,blackbackedwoodpecker,bkbwoo,blackbackedwoodpecker,picoides-arcticus,
dryobates-pubescens,downywoodpecker,dowwoo,downywoodpecker,dryobates-pubescens,
dryobates-scalaris,ladderbackedwoodpecker,labwoo,ladderbackedwoodpecker,dryobates-scalaris,
leuconotopicus-borealis,redcockadedwoodpecker,recwoo,redcockadedwoodpecker,leuconotopicus-borealis,"Same species, different scientific name"
leuconotopicus-villosus,hairywoodpecker,haiwoo,hairywoodpecker,leuconotopicus-villosus,"Same species, different scientific name"
colaptes-auratus,northernflicker,norfli,northernflicker,colaptes-auratus,
dryocopus-pileatus,pileatedwoodpecker,pilwoo,pileatedwoodpecker,dryocopus-pileatus,
falco-sparverius,americankestrel,amekes,americankestrel,falco-sparverius,
falco-columbarius,merlin,merlin,merlin,falco-columbarius,
falco-peregrinus,peregrinefalcon,perfal,peregrinefalcon,falco-peregrinus,
myiopsitta-monachus,monkparakeet,monpar,monkparakeet,myiopsitta-monachus,
psittacula-krameri,roseringedparakeet,rorpar,roseringedparakeet,psittacula-krameri,
agapornis-roseicollis,rosyfacedlovebird,peflov,rosyfacedlovebird,agapornis-roseicollis,
camptostoma-imberbe,northernbeardlesstyrannulet,nobtyr,northernbeardlesstyrannulet,camptostoma-imberbe,
myiarchus-tuberculifer,duskycappedflycatcher,ducfly,duskycappedflycatcher,myiarchus-tuberculifer,
myiarchus-cinerascens,ashthroatedflycatcher,astfly,ashthroatedflycatcher,myiarchus-cinerascens,
myiarchus-crinitus,greatcrestedflycatcher,grcfly,greatcrestedflycatcher,myiarchus-crinitus,
myiarchus-tyrannulus,browncrestedflycatcher,bncfly,browncrestedflycatcher,myiarchus-tyrannulus,
pitangus-sulphuratus,greatkiskadee,grekis,greatkiskadee,pitangus-sulphuratus,
myiodynastes-luteiventris,sulphurbelliedflycatcher,subfly,sulphurbelliedflycatcher,myiodynastes-luteiventris,
tyrannus-melancholicus,tropicalkingbird,trokin,tropicalkingbird,tyrannus-melancholicus,
tyrannus-couchii,couchskingbird,coukin,couchskingbird,tyrannus-couchii,
tyrannus-vociferans,cassinskingbird,caskin,cassinskingbird,tyrannus-vociferans,
tyrannus-crassirostris,thickbilledkingbird,thbkin,thickbilledkingbird,tyrannus-crassirostris,
tyrannus-verticalis,westernkingbird,weskin,westernkingbird,tyrannus-verticalis,
tyrannus-tyrannus,easternkingbird,easkin,easternkingbird,tyrannus-tyrannus,
tyrannus-dominicensis,graykingbird,grykin,graykingbird,tyrannus-dominicensis,
tyrannus-forficatus,scissortailedflycatcher,sctfly,scissortailedflycatcher,tyrannus-forficatus,
contopus-cooperi,olivesidedflycatcher,olsfly,olivesidedflycatcher,contopus-cooperi,
contopus-pertinax,greaterpewee,grepew,greaterpewee,contopus-pertinax,
contopus-sordidulus,westernwoodpewee,wewpew,westernwoodpewee,contopus-sordidulus,
contopus-virens,easternwoodpewee,eawpew,easternwoodpewee,contopus-virens,
empidonax-flaviventris,yellowbelliedflycatcher,yebfly,yellowbelliedflycatcher,empidonax-flaviventris,
empidonax-virescens,acadianflycatcher,acafly,acadianflycatcher,empidonax-virescens,
empidonax-alnorum,alderflycatcher,aldfly,alderflycatcher,empidonax-alnorum,
empidonax-traillii,willowflycatcher,wilfly,willowflycatcher,empidonax-traillii,
empidonax-minimus,leastflycatcher,leafly,leastflycatcher,empidonax-minimus,
empidonax-hammondii,hammondsflycatcher,hamfly,hammondsflycatcher,empidonax-hammondii,
empidonax-wrightii,americangrayflycatcher,gryfly,grayflycatcher,empidonax-wrightii,"Same species, different common name"
empidonax-oberholseri,americanduskyflycatcher,dusfly,duskyflycatcher,empidonax-oberholseri,"Same species, different common name"
empidonax-difficilis,pacificslopeflycatcher,pasfly,pacificslopeflycatcher,empidonax-difficilis,
empidonax-occidentalis,cordilleranflycatcher,corfly,cordilleranflycatcher,empidonax-occidentalis,
empidonax-fulvifrons,buffbreastedflycatcher,bubfly,buffbreastedflycatcher,empidonax-fulvifrons,
sayornis-nigricans,blackphoebe,blkpho,blackphoebe,sayornis-nigricans,
sayornis-phoebe,easternphoebe,easpho,easternphoebe,sayornis-phoebe,
sayornis-saya,saysphoebe,saypho,saysphoebe,sayornis-saya,
pyrocephalus-obscurus,vermilionflycatcher,verfly,vermilionflycatcher,pyrocephalus-obscurus,"Same species, different common name"
lanius-ludovicianus,loggerheadshrike,logshr,loggerheadshrike,lanius-ludovicianus,
vireo-atricapilla,blackcappedvireo,bkcvir1,blackcappedvireo,vireo-atricapilla,
vireo-griseus,whiteeyedvireo,whevir,whiteeyedvireo,vireo-griseus,
vireo-bellii,bellsvireo,belvir,bellsvireo,vireo-bellii,
vireo-vicinior,grayvireo,gryvir,grayvireo,vireo-vicinior,
vireo-huttoni,huttonsvireo,hutvir,huttonsvireo,vireo-huttoni,
vireo-flavifrons,yellowthroatedvireo,yetvir,yellowthroatedvireo,vireo-flavifrons,
vireo-cassinii,cassinsvireo,casvir,cassinsvireo,vireo-cassinii,
vireo-solitarius,blueheadedvireo,buhvir,blueheadedvireo,vireo-solitarius,
vireo-plumbeus,plumbeousvireo,plsvir,plumbeousvireo,vireo-plumbeus,
vireo-philadelphicus,philadelphiavireo,phivir,philadelphiavireo,vireo-philadelphicus,
vireo-gilvus,warblingvireo,warvir,warblingvireo,vireo-gilvus,
vireo-olivaceus,redeyedvireo,reevir1,redeyedvireo,vireo-olivaceus,
vireo-altiloquus,blackwhiskeredvireo,bkwvir,blackwhiskeredvireo,vireo-altiloquus,
perisoreus-canadensis,grayjay,gryjay,canadajay,perisoreus-canadensis,"Same species, different common name"
cyanocorax-luxuosus,greenjay,grnjay,greenjay,cyanocorax-luxuosus,"Same species, different scientific name"
gymnorhinus-cyanocephalus,pinyonjay,pinjay,pinyonjay,gymnorhinus-cyanocephalus,
cyanocitta-stelleri,stellersjay,stejay,stellersjay,cyanocitta-stelleri,
cyanocitta-cristata,bluejay,blujay,bluejay,cyanocitta-cristata,
aphelocoma-californica,californiascrubjay,cowscj1,californiascrubjay,aphelocoma-californica,
aphelocoma-woodhouseii,woodhousesscrubjay,wooscj2,woodhousesscrubjay,aphelocoma-woodhouseii,
aphelocoma-wollweberi,mexicanjay,mexjay4,mexicanjay,aphelocoma-wollweberi,
nucifraga-columbiana,clarksnutcracker,clanut,clarksnutcracker,nucifraga-columbiana,
pica-hudsonia,blackbilledmagpie,bkbmag1,blackbilledmagpie,pica-hudsonia,
pica-nuttalli,yellowbilledmagpie,yebmag,yellowbilledmagpie,pica-nuttalli,
corvus-brachyrhynchos,americancrow,amecro,americancrow,corvus-brachyrhynchos,
corvus-caurinus,northwesterncrow,norcro,northwesterncrow,corvus-caurinus,
corvus-ossifragus,fishcrow,fiscro,fishcrow,corvus-ossifragus,
corvus-corax,northernraven,comrav,commonraven,corvus-corax,"Same species, different common name"
alauda-arvensis,eurasianskylark,skylar,eurasianskylark,alauda-arvensis,
eremophila-alpestris,hornedlark,horlar,hornedlark,eremophila-alpestris,
progne-subis,purplemartin,purmar,purplemartin,progne-subis,
tachycineta-bicolor,treeswallow,treswa,treeswallow,tachycineta-bicolor,
tachycineta-thalassina,violetgreenswallow,vigswa,violetgreenswallow,tachycineta-thalassina,
riparia-riparia,sandmartin,banswa,bankswallow,riparia-riparia,"Same species, different common name"
petrochelidon-pyrrhonota,americancliffswallow,cliswa,cliffswallow,petrochelidon-pyrrhonota,"Same species, different common name"
petrochelidon-fulva,caveswallow,cavswa,caveswallow,petrochelidon-fulva,
hirundo-rustica,barnswallow,barswa,barnswallow,hirundo-rustica,
poecile-carolinensis,carolinachickadee,carchi,carolinachickadee,poecile-carolinensis,
poecile-atricapillus,blackcappedchickadee,bkcchi,blackcappedchickadee,poecile-atricapillus,
poecile-gambeli,mountainchickadee,mouchi,mountainchickadee,poecile-gambeli,
poecile-sclateri,mexicanchickadee,mexchi,mexicanchickadee,poecile-sclateri,
poecile-rufescens,chestnutbackedchickadee,chbchi,chestnutbackedchickadee,poecile-rufescens,
poecile-hudsonicus,borealchickadee,borchi2,borealchickadee,poecile-hudsonicus,
baeolophus-wollweberi,bridledtitmouse,britit,bridledtitmouse,baeolophus-wollweberi,
baeolophus-inornatus,oaktitmouse,oaktit,oaktitmouse,baeolophus-inornatus,
baeolophus-ridgwayi,junipertitmouse,juntit1,junipertitmouse,baeolophus-ridgwayi,
baeolophus-bicolor,tuftedtitmouse,tuftit,tuftedtitmouse,baeolophus-bicolor,
baeolophus-atricristatus,blackcrestedtitmouse,blctit4,blackcrestedtitmouse,baeolophus-atricristatus,
auriparus-flaviceps,verdin,verdin,verdin,auriparus-flaviceps,
psaltriparus-minimus,americanbushtit,bushti,bushtit,psaltriparus-minimus,"Same species, different common name"
sitta-canadensis,redbreastednuthatch,rebnut,redbreastednuthatch,sitta-canadensis,
sitta-carolinensis,whitebreastednuthatch,whbnut,whitebreastednuthatch,sitta-carolinensis,
sitta-pygmaea,pygmynuthatch,pygnut,pygmynuthatch,sitta-pygmaea,
sitta-pusilla,brownheadednuthatch,bnhnut,brownheadednuthatch,sitta-pusilla,
certhia-americana,browncreeper,brncre,browncreeper,certhia-americana,
salpinctes-obsoletus,rockwren,rocwre,rockwren,salpinctes-obsoletus,
catherpes-mexicanus,canyonwren,canwre,canyonwren,catherpes-mexicanus,
troglodytes-aedon,housewren,houwre,housewren,troglodytes-aedon,
troglodytes-pacificus,pacificwren,pacwre1,pacificwren,troglodytes-pacificus,
troglodytes-hiemalis,winterwren,winwre3,winterwren,troglodytes-hiemalis,
cistothorus-stellaris,sedgewren,sedwre,sedgewren,cistothorus-stellaris,"Same species, different scientific name"
cistothorus-palustris,marshwren,marwre,marshwren,cistothorus-palustris,
thryothorus-ludovicianus,carolinawren,carwre,carolinawren,thryothorus-ludovicianus,
thryomanes-bewickii,bewickswren,bewwre,bewickswren,thryomanes-bewickii,
campylorhynchus-brunneicapillus,cactuswren,cacwre,cactuswren,campylorhynchus-brunneicapillus,
polioptila-caerulea,bluegraygnatcatcher,buggna,bluegraygnatcatcher,polioptila-caerulea,
polioptila-californica,californiagnatcatcher,calgna,californiagnatcatcher,polioptila-californica,
polioptila-melanura,blacktailedgnatcatcher,bktgna,blacktailedgnatcatcher,polioptila-melanura,
pycnonotus-cafer,redventedbulbul,revbul,redventedbulbul,pycnonotus-cafer,
pycnonotus-jocosus,redwhiskeredbulbul,rewbul,redwhiskeredbulbul,pycnonotus-jocosus,
regulus-satrapa,goldencrownedkinglet,gockin,goldencrownedkinglet,regulus-satrapa,
regulus-calendula,rubycrownedkinglet,ruckin,rubycrownedkinglet,regulus-calendula,
horornis-diphone,japanesebushwarbler,jabwar,japanesebushwarbler,horornis-diphone,
phylloscopus-borealis,arcticwarbler,arcwar1,arcticwarbler,phylloscopus-borealis,
chamaea-fasciata,wrentit,wrenti,wrentit,chamaea-fasciata,
zosterops-japonicus,warblingwhiteeye,jaweye,japanesewhiteeye,zosterops-japonicus,"Same species, different common name"
luscinia-svecica,bluethroat,blueth,bluethroat,luscinia-svecica,
oenanthe-oenanthe,northernwheatear,norwhe,northernwheatear,oenanthe-oenanthe,
sialia-sialis,easternbluebird,easblu,easternbluebird,sialia-sialis,
myadestes-townsendi,townsendssolitaire,towsol,townsendssolitaire,myadestes-townsendi,
catharus-fuscescens,veery,veery,veery,catharus-fuscescens,
catharus-minimus,graycheekedthrush,gycthr,graycheekedthrush,catharus-minimus,
catharus-bicknelli,bicknellsthrush,bicthr,bicknellsthrush,catharus-bicknelli,
catharus-ustulatus,swainsonsthrush,swathr,swainsonsthrush,catharus-ustulatus,
catharus-guttatus,hermitthrush,herthr,hermitthrush,catharus-guttatus,
hylocichla-mustelina,woodthrush,woothr,woodthrush,hylocichla-mustelina,
turdus-migratorius,americanrobin,amerob,americanrobin,turdus-migratorius,
ixoreus-naevius,variedthrush,varthr,variedthrush,ixoreus-naevius,
dumetella-carolinensis,graycatbird,grycat,graycatbird,dumetella-carolinensis,
toxostoma-curvirostre,curvebilledthrasher,cubthr,curvebilledthrasher,toxostoma-curvirostre,
toxostoma-rufum,brownthrasher,brnthr,brownthrasher,toxostoma-rufum,
toxostoma-longirostre,longbilledthrasher,lobthr,longbilledthrasher,toxostoma-longirostre,
toxostoma-bendirei,bendiresthrasher,benthr,bendiresthrasher,toxostoma-bendirei,
toxostoma-redivivum,californiathrasher,calthr,californiathrasher,toxostoma-redivivum,
toxostoma-lecontei,lecontesthrasher,lecthr,lecontesthrasher,toxostoma-lecontei,
toxostoma-crissale,crissalthrasher,crithr,crissalthrasher,toxostoma-crissale,
oreoscoptes-montanus,sagethrasher,sagthr,sagethrasher,oreoscoptes-montanus,
mimus-polyglottos,northernmockingbird,normoc,northernmockingbird,mimus-polyglottos,
sturnus-vulgaris,commonstarling,eursta,europeanstarling,sturnus-vulgaris,"Same species, different common name"
acridotheres-tristis,commonmyna,commyn,commonmyna,acridotheres-tristis,
bombycilla-garrulus,bohemianwaxwing,bohwax,bohemianwaxwing,bombycilla-garrulus,
bombycilla-cedrorum,cedarwaxwing,cedwax,cedarwaxwing,bombycilla-cedrorum,
phainopepla-nitens,phainopepla,phaino,phainopepla,phainopepla-nitens,
peucedramus-taeniatus,olivewarbler,oliwar,olivewarbler,peucedramus-taeniatus,
estrilda-astrild,commonwaxbill,comwax,commonwaxbill,estrilda-astrild,
passer-domesticus,housesparrow,houspa,housesparrow,passer-domesticus,
passer-montanus,eurasiantreesparrow,eutspa,eurasiantreesparrow,passer-montanus,
motacilla-tschutschensis,easternyellowwagtail,eaywag,easternyellowwagtail,motacilla-tschutschensis,
anthus-rubescens,buffbelliedpipit,amepip,americanpipit,anthus-rubescens,"Same species, different common name"
anthus-spragueii,spraguespipit,sprpip,spraguespipit,anthus-spragueii,
hesperiphona-vespertina,eveninggrosbeak,evegro,eveninggrosbeak,hesperiphona-vespertina,"Same species, different scientific name"
himatione-sanguinea,apapane,apapan,apapane,himatione-sanguinea,
pinicola-enucleator,pinegrosbeak,pingro,pinegrosbeak,pinicola-enucleator,
haemorhous-mexicanus,housefinch,houfin,housefinch,haemorhous-mexicanus,
haemorhous-purpureus,purplefinch,purfin,purplefinch,haemorhous-purpureus,
haemorhous-cassinii,cassinsfinch,casfin,cassinsfinch,haemorhous-cassinii,
crithagra-mozambica,yellowfrontedcanary,yefcan,yellowfrontedcanary,crithagra-mozambica,
acanthis-flammea,commonredpoll,comred,commonredpoll,acanthis-flammea,
acanthis-hornemanni,arcticredpoll,hoared,hoaryredpoll,acanthis-hornemanni,"Same species, different common name"
loxia-curvirostra,redcrossbill,redcro,redcrossbill,loxia-curvirostra,
loxia-leucoptera,twobarredcrossbill,whwcro,whitewingedcrossbill,loxia-leucoptera,"Same species, different common name"
spinus-pinus,pinesiskin,pinsis,pinesiskin,spinus-pinus,
spinus-psaltria,lessergoldfinch,lesgol,lessergoldfinch,spinus-psaltria,
spinus-lawrencei,lawrencesgoldfinch,lawgol,lawrencesgoldfinch,spinus-lawrencei,
spinus-tristis,americangoldfinch,amegfi,americangoldfinch,spinus-tristis,
calcarius-lapponicus,laplandlongspur,laplon,laplandlongspur,calcarius-lapponicus,
calcarius-ornatus,chestnutcollaredlongspur,chclon,chestnutcollaredlongspur,calcarius-ornatus,
plectrophenax-nivalis,snowbunting,snobun,snowbunting,plectrophenax-nivalis,
arremonops-rufivirgatus,olivesparrow,olispa,olivesparrow,arremonops-rufivirgatus,
pipilo-chlorurus,greentailedtowhee,gnttow,greentailedtowhee,pipilo-chlorurus,
pipilo-maculatus,spottedtowhee,spotow,spottedtowhee,pipilo-maculatus,
pipilo-erythrophthalmus,easterntowhee,eastow,easterntowhee,pipilo-erythrophthalmus,
aimophila-ruficeps,rufouscrownedsparrow,rucspa,rufouscrownedsparrow,aimophila-ruficeps,
melozone-fusca,canyontowhee,cantow,canyontowhee,melozone-fusca,
melozone-crissalis,californiatowhee,caltow,californiatowhee,melozone-crissalis,
melozone-aberti,abertstowhee,abetow,abertstowhee,melozone-aberti,
peucaea-carpalis,rufouswingedsparrow,ruwspa,rufouswingedsparrow,peucaea-carpalis,
peucaea-botterii,botterissparrow,botspa,botterissparrow,peucaea-botterii,
peucaea-cassinii,cassinssparrow,casspa,cassinssparrow,peucaea-cassinii,
peucaea-aestivalis,bachmanssparrow,bacspa,bachmanssparrow,peucaea-aestivalis,
spizelloides-arborea,americantreesparrow,amtspa,americantreesparrow,spizelloides-arborea,
spizella-passerina,chippingsparrow,chispa,chippingsparrow,spizella-passerina,
spizella-pallida,claycoloredsparrow,clcspa,claycoloredsparrow,spizella-pallida,
spizella-breweri,brewerssparrow,brespa,brewerssparrow,spizella-breweri,
spizella-pusilla,fieldsparrow,fiespa,fieldsparrow,spizella-pusilla,
spizella-atrogularis,blackchinnedsparrow,bkcspa,blackchinnedsparrow,spizella-atrogularis,
pooecetes-gramineus,vespersparrow,vesspa,vespersparrow,pooecetes-gramineus,
chondestes-grammacus,larksparrow,larspa,larksparrow,chondestes-grammacus,
amphispiza-bilineata,blackthroatedsparrow,bktspa,blackthroatedsparrow,amphispiza-bilineata,
artemisiospiza-nevadensis,sagebrushsparrow,sagspa1,sagebrushsparrow,artemisiospiza-nevadensis,
artemisiospiza-belli,bellssparrow,belspa2,bellssparrow,artemisiospiza-belli,
calamospiza-melanocorys,larkbunting,larbun,larkbunting,calamospiza-melanocorys,
passerculus-sandwichensis,savannahsparrow,savspa,savannahsparrow,passerculus-sandwichensis,
ammodramus-savannarum,grasshoppersparrow,graspa,grasshoppersparrow,ammodramus-savannarum,
ammodramus-bairdii,bairdssparrow,baispa,bairdssparrow,ammodramus-bairdii,"Same species, different scientific name"
ammodramus-henslowii,henslowssparrow,henspa,henslowssparrow,ammodramus-henslowii,"Same species, different scientific name"
ammodramus-leconteii,lecontessparrow,lecspa,lecontessparrow,ammodramus-leconteii,"Same species, different scientific name"
ammodramus-maritimus,seasidesparrow,seaspa,seasidesparrow,ammodramus-maritimus,"Same species, different scientific name"
ammodramus-nelsoni,nelsonssparrow,nstspa,nelsonssparrow,ammodramus-nelsoni,"Same species, different scientific name"
passerella-iliaca,redfoxsparrow,foxspa,foxsparrow,,XC split with multiple species in the ABA area; BirdNet's name for the entire complex (passerella-iliaca) refers to one of the ABA XC subspecies
melospiza-melodia,songsparrow,sonspa,songsparrow,melospiza-melodia,
melospiza-lincolnii,lincolnssparrow,linspa,lincolnssparrow,melospiza-lincolnii,
melospiza-georgiana,swampsparrow,swaspa,swampsparrow,melospiza-georgiana,
zonotrichia-albicollis,whitethroatedsparrow,whtspa,whitethroatedsparrow,zonotrichia-albicollis,
zonotrichia-querula,harrisssparrow,harspa,harrisssparrow,zonotrichia-querula,
zonotrichia-leucophrys,whitecrownedsparrow,whcspa,whitecrownedsparrow,zonotrichia-leucophrys,
zonotrichia-atricapilla,goldencrownedsparrow,gocspa,goldencrownedsparrow,zonotrichia-atricapilla,
junco-hyemalis,darkeyedjunco,daejun,darkeyedjunco,junco-hyemalis,
junco-phaeonotus,yelloweyedjunco,yeejun,yelloweyedjunco,junco-phaeonotus,
icteria-virens,yellowbreastedchat,yebcha,yellowbreastedchat,icteria-virens,
xanthocephalus-xanthocephalus,yellowheadedblackbird,yehbla,yellowheadedblackbird,xanthocephalus-xanthocephalus,
dolichonyx-oryzivorus,bobolink,boboli,bobolink,dolichonyx-oryzivorus,
sturnella-magna,easternmeadowlark,easmea,easternmeadowlark,sturnella-magna,
sturnella-neglecta,westernmeadowlark,wesmea,westernmeadowlark,sturnella-neglecta,
icterus-spurius,orchardoriole,orcori,orchardoriole,icterus-spurius,
icterus-cucullatus,hoodedoriole,hooori,hoodedoriole,icterus-cucullatus,
icterus-bullockii,bullocksoriole,bulori,bullocksoriole,icterus-bullockii,
icterus-gularis,altamiraoriole,altori,altamiraoriole,icterus-gularis,
icterus-graduacauda,audubonsoriole,audori,audubonsoriole,icterus-graduacauda,
icterus-galbula,baltimoreoriole,balori,baltimoreoriole,icterus-galbula,
icterus-parisorum,scottsoriole,scoori,scottsoriole,icterus-parisorum,
agelaius-phoeniceus,redwingedblackbird,rewbla,redwingedblackbird,agelaius-phoeniceus,
agelaius-tricolor,tricoloredblackbird,tribla,tricoloredblackbird,agelaius-tricolor,
molothrus-ater,brownheadedcowbird,bnhcow,brownheadedcowbird,molothrus-ater,
euphagus-carolinus,rustyblackbird,rusbla,rustyblackbird,euphagus-carolinus,
euphagus-cyanocephalus,brewersblackbird,brebla,brewersblackbird,euphagus-cyanocephalus,
quiscalus-quiscula,commongrackle,comgra,commongrackle,quiscalus-quiscula,
quiscalus-major,boattailedgrackle,botgra,boattailedgrackle,quiscalus-major,
quiscalus-mexicanus,greattailedgrackle,grtgra,greattailedgrackle,quiscalus-mexicanus,
seiurus-aurocapilla,ovenbird,ovenbi1,ovenbird,seiurus-aurocapilla,
helmitheros-vermivorum,wormeatingwarbler,woewar1,wormeatingwarbler,helmitheros-vermivorum,
parkesia-motacilla,louisianawaterthrush,louwat,louisianawaterthrush,parkesia-motacilla,
parkesia-noveboracensis,northernwaterthrush,norwat,northernwaterthrush,parkesia-noveboracensis,
vermivora-chrysoptera,goldenwingedwarbler,gowwar,goldenwingedwarbler,vermivora-chrysoptera,
vermivora-cyanoptera,bluewingedwarbler,buwwar,bluewingedwarbler,vermivora-cyanoptera,
mniotilta-varia,blackandwhitewarbler,bawwar,blackandwhitewarbler,mniotilta-varia,
protonotaria-citrea,prothonotarywarbler,prowar,prothonotarywarbler,protonotaria-citrea,
limnothlypis-swainsonii,swainsonswarbler,swawar,swainsonswarbler,limnothlypis-swainsonii,
leiothlypis-peregrina,tennesseewarbler,tenwar,tennesseewarbler,leiothlypis-peregrina,"Same species, different scientific name"
leiothlypis-celata,orangecrownedwarbler,orcwar,orangecrownedwarbler,leiothlypis-celata,"Same species, different scientific name"
leiothlypis-luciae,lucyswarbler,lucwar,lucyswarbler,leiothlypis-luciae,"Same species, different scientific name"
leiothlypis-ruficapilla,nashvillewarbler,naswar,nashvillewarbler,leiothlypis-ruficapilla,"Same species, different scientific name"
leiothlypis-virginiae,virginiaswarbler,virwar,virginiaswarbler,leiothlypis-virginiae,"Same species, different scientific name"
oporornis-agilis,connecticutwarbler,conwar,connecticutwarbler,oporornis-agilis,
geothlypis-tolmiei,macgillivrayswarbler,macwar,macgillivrayswarbler,geothlypis-tolmiei,
geothlypis-philadelphia,mourningwarbler,mouwar,mourningwarbler,geothlypis-philadelphia,
geothlypis-formosa,kentuckywarbler,kenwar,kentuckywarbler,geothlypis-formosa,
geothlypis-trichas,commonyellowthroat,comyel,commonyellowthroat,geothlypis-trichas,
setophaga-citrina,hoodedwarbler,hoowar,hoodedwarbler,setophaga-citrina,
setophaga-ruticilla,americanredstart,amered,americanredstart,setophaga-ruticilla,
setophaga-kirtlandii,kirtlandswarbler,kirwar,kirtlandswarbler,setophaga-kirtlandii,
setophaga-tigrina,capemaywarbler,camwar,capemaywarbler,setophaga-tigrina,
setophaga-cerulea,ceruleanwarbler,cerwar,ceruleanwarbler,setophaga-cerulea,
setophaga-americana,northernparula,norpar,northernparula,setophaga-americana,
setophaga-magnolia,magnoliawarbler,magwar,magnoliawarbler,setophaga-magnolia,
setophaga-castanea,baybreastedwarbler,babwar,baybreastedwarbler,setophaga-castanea,
setophaga-fusca,blackburnianwarbler,bkbwar,blackburnianwarbler,setophaga-fusca,
setophaga-aestiva,americanyellowwarbler,yelwar,yellowwarbler,setophaga-aestiva,XC split with only one species in the ABA area; BirdNet's name for the complex (setophaga-petechia) refers to the XC species INSIDE the ABA area
setophaga-pensylvanica,chestnutsidedwarbler,chswar,chestnutsidedwarbler,setophaga-pensylvanica,
setophaga-striata,blackpollwarbler,bkpwar,blackpollwarbler,setophaga-striata,
setophaga-caerulescens,blackthroatedbluewarbler,btbwar,blackthroatedbluewarbler,setophaga-caerulescens,
setophaga-palmarum,palmwarbler,palwar,palmwarbler,setophaga-palmarum,
setophaga-pinus,pinewarbler,pinwar,pinewarbler,setophaga-pinus,
setophaga-coronata,myrtlewarbler,yerwar,yellowrumpedwarbler,,XC split with multiple species in the ABA area; BirdNet's name for the complex (setophaga-coronata) refers to one of the XC subspecies
setophaga-dominica,yellowthroatedwarbler,yetwar,yellowthroatedwarbler,setophaga-dominica,
setophaga-discolor,prairiewarbler,prawar,prairiewarbler,setophaga-discolor,
setophaga-graciae,graceswarbler,grawar,graceswarbler,setophaga-graciae,
setophaga-nigrescens,blackthroatedgraywarbler,btywar,blackthroatedgraywarbler,setophaga-nigrescens,
setophaga-townsendi,townsendswarbler,towwar,townsendswarbler,setophaga-townsendi,
setophaga-occidentalis,hermitwarbler,herwar,hermitwarbler,setophaga-occidentalis,
setophaga-virens,blackthroatedgreenwarbler,btnwar,blackthroatedgreenwarbler,setophaga-virens,
cardellina-canadensis,canadawarbler,canwar,canadawarbler,cardellina-canadensis,
cardellina-pusilla,wilsonswarbler,wlswar,wilsonswarbler,cardellina-pusilla,
cardellina-rubrifrons,redfacedwarbler,refwar,redfacedwarbler,cardellina-rubrifrons,
myioborus-pictus,paintedwhitestart,paired,paintedredstart,myioborus-pictus,"Same species, different common name"
piranga-hepatica,hepatictanager,,,,XC split with only one species in the ABA area; BirdNet's name for the complex (piranga-flava) refers to the XC species outside the ABA area
piranga-rubra,summertanager,sumtan,summertanager,piranga-rubra,
piranga-olivacea,scarlettanager,scatan,scarlettanager,piranga-olivacea,
piranga-ludoviciana,westerntanager,westan,westerntanager,piranga-ludoviciana,
cardinalis-cardinalis,northerncardinal,norcar,northerncardinal,cardinalis-cardinalis,
cardinalis-sinuatus,pyrrhuloxia,pyrrhu,pyrrhuloxia,cardinalis-sinuatus,
pheucticus-ludovicianus,rosebreastedgrosbeak,robgro,rosebreastedgrosbeak,pheucticus-ludovicianus,
pheucticus-melanocephalus,blackheadedgrosbeak,bkhgro,blackheadedgrosbeak,pheucticus-melanocephalus,
passerina-caerulea,bluegrosbeak,blugrb1,bluegrosbeak,passerina-caerulea,
passerina-amoena,lazulibunting,lazbun,lazulibunting,passerina-amoena,
passerina-cyanea,indigobunting,indbun,indigobunting,passerina-cyanea,
passerina-versicolor,variedbunting,varbun,variedbunting,passerina-versicolor,
passerina-ciris,paintedbunting,paibun,paintedbunting,passerina-ciris,
spiza-americana,dickcissel,dickci,dickcissel,spiza-americana,
paroaria-coronata,redcrestedcardinal,reccar,redcrestedcardinal,paroaria-coronata,
sicalis-flaveola,saffronfinch,saffin,saffronfinch,sicalis-flaveola,
passerella-unalaschcensis,sootyfoxsparrow,,,,XC split with multiple species in the ABA area; BirdNet's name for the entire complex (passerella-iliaca) refers to one of the ABA XC subspecies
passerella-schistacea,slatecoloredfoxsparrow,,,,XC split with multiple species in the ABA area; BirdNet's name for the entire complex (passerella-iliaca) refers to one of the ABA XC subspecies
passerella-megarhyncha,thickbilledfoxsparrow,,,,XC split with multiple species in the ABA area; BirdNet's name for the entire complex (passerella-iliaca) refers to one of the ABA XC subspecies
setophaga-auduboni,audubonswarbler,,,,XC split with multiple species in the ABA area; BirdNet's name for the complex (setophaga-coronata) refers to one of the XC ABA subspecies
"""

species_table = pd.read_csv(StringIO(species_table_str))
